<?php

/*
Plugin Name: WP Facebook Like Send & Open Graph Meta
Version: 1.2.2
Description: Add Facebook Like and Send buttons after each post. Automatically include Open Graph Meta Tags
Author: Marvie Pons
Author URI: http://triptripper.com/
Donate URI: http://tutorials.triptripper.com/
Plugin URI: http://tutorials.triptripper.com/facebook-like-send-opengraph-wp-plugin/
  
Copyright 2012  Marvie Pons (email: celebritybanderas@gmail.com)

Released under GPL License.
*/

define('FBLSOGM_VERSION', '1.2.2');

// REQUIRE MINIMUM VERSION OF WORDPRESS:                                               

function fblsogm_requires_wordpress_version() {
	global $wp_version;
	$plugin = plugin_basename( __FILE__ );
	$plugin_data = get_plugin_data( __FILE__, false );

	if ( version_compare($wp_version, "3.0", "<" ) ) {
		if( is_plugin_active($plugin) ) {
			deactivate_plugins( $plugin );
			wp_die( "'".$plugin_data['Name']."' requires WordPress 3.0 or higher, and has been deactivated! Please upgrade WordPress and try again.<br /><br />Back to <a href='".admin_url()."'>WordPress admin</a>." );
		}
	}
}
add_action( 'admin_init', 'fblsogm_requires_wordpress_version' );

// Set-up Action and Filter Hooks
register_activation_hook(__FILE__, 'fblsogm_add_defaults');
register_uninstall_hook(__FILE__, 'fblsogm_delete_plugin_options');
add_action('admin_init', 'fblsogm_init' );
add_action('admin_menu', 'fblsogm_add_options_page');
add_filter( 'plugin_action_links', 'fblsogm_plugin_action_links', 10, 2 );

// Delete options table entries ONLY when plugin deactivated AND deleted
function fblsogm_delete_plugin_options() {
	delete_option('fblsogm_options');
}

// Define default option settings
function fblsogm_add_defaults() {
	$tmp = get_option('fblsogm_options');
    if(($tmp['chk_default_options_db']=='1')||(!is_array($tmp))) {
		delete_option('fblsogm_options'); // so we don't have to reset all the 'off' checkboxes too! (don't think this is needed but leave for now)
		$arr = array(	"drp_select_box" => "true",
						"drp_select_box2" => "light",
						"drp_select_box3" => "like",
						"drp_select_font" => "arial",
						"drp_select_layout" => "standard",
						"txt_one" => ""
		);
		update_option('fblsogm_options', $arr);
	}
}

// Init plugin options to white list our options
function fblsogm_init(){
	register_setting( 'fblsogm_plugin_options', 'fblsogm_options', 'fblsogm_validate_options' );
}

// Add menu page
function fblsogm_add_options_page() {
	add_options_page('WP Facebook Like Send & Open Graph Meta Options Page', 'Facebook Like Send', 'manage_options', 'fblsogm', 'fblsogm_render_form');
}

// Render the Plugin options form
function fblsogm_render_form() {
	?>
	<div class="wrap">
	
	<!-- Display Plugin Icon, Header, and Description -->
	
	<div class="icon32" id="icon-options-general"><br></div>
	<h2>WP Facebook Like Send & Open Graph Meta Plugin v<?php echo FBLSOGM_VERSION; ?></h2>
	<p>To easily customize WP Facebook Like Send & Open Graph Meta, use the options below.</p>
	
	<!-- Side Info Column -->
	
	<div id="poststuff" class="metabox-holder has-right-sidebar">
	
		<!-- Plugin Options Column -->

		<div id="post-body" class="has-sidebar">
			<div id="post-body-content" class="has-sidebar-content">
				<div id="normal-sortables" class="meta-box-sortables">
					<div id="about" class="postbox">
						<div class="inside">		
		

		<!-- Beginning of the Plugin Options Form -->
		<form method="post" action="options.php">
			<?php settings_fields('fblsogm_plugin_options'); ?>
			<?php $options = get_option('fblsogm_options'); ?>

			<!-- Table Structure Containing Form Controls -->
			<!-- Each Plugin Option Defined on a New Table Row -->
			<table class="form-table">
				
				<!-- Checkbox Buttons -->
				<tr valign="top">
					<th scope="row">Enable Buttons on Homepage</th>
					<td>
						<!-- First checkbox button -->
						<label><input name="fblsogm_options[chk_button1]" type="checkbox" value="1" <?php if (isset($options['chk_button1'])) { checked('1', $options['chk_button1']); } ?> /> Check this box if you want the buttons to show on homepage as well</label><br />
											
					</td>
				</tr>
				
				<!-- Select Drop-Down Control -->
				<tr>
					<th scope="row">Layout Style</th>
					<td>
						<select name='fblsogm_options[drp_select_layout]'>
							<option value='standard' <?php selected('standard', $options['drp_select_layout']); ?>>standard</option>
							<option value='button_count' <?php selected('button_count', $options['drp_select_layout']); ?>>button_count</option>
							<option value='box_count' <?php selected('box_count', $options['drp_select_layout']); ?>>box_count</option>
						</select>
						<span style="color:#666666;margin-left:2px;">Determines the size and amount of social context next to the button</span>
					</td>
				</tr>
				
				<!-- Select Drop-Down Control -->
				<tr>
					<th scope="row">Show Faces</th>
					<td>
						<select name='fblsogm_options[drp_select_box]'>
							<option value='true' <?php selected('true', $options['drp_select_box']); ?>>Show</option>
							<option value='false' <?php selected('false', $options['drp_select_box']); ?>>Hide</option>
						</select>
						<span style="color:#666666;margin-left:2px;">Show or Hide profile pictures below the buttons</span>
					</td>
				</tr>
				
				<!-- Select Drop-Down Control -->
				<tr>
					<th scope="row">Font</th>
					<td>
						<select name='fblsogm_options[drp_select_font]'>
							<option value='arial' <?php selected('arial', $options['drp_select_font']); ?>>Arial</option>
							<option value='lucida+grande' <?php selected('lucida+grande', $options['drp_select_font']); ?>>Lucida Grande</option>
							<option value='segoe+ui' <?php selected('segoe+ui', $options['drp_select_font']); ?>>Segoe UI</option>
							<option value='tahoma' <?php selected('tahoma', $options['drp_select_font']); ?>>Tahoma</option>
							<option value='trebuchet+ms' <?php selected('trebuchet+ms', $options['drp_select_font']); ?>>Trebuchet MS</option>
							<option value='verdana' <?php selected('verdana', $options['drp_select_font']); ?>>Verdana</option>
						</select>
						<span style="color:#666666;margin-left:2px;">The font of the plugin</span>
					</td>
				</tr>

				<!-- Select Drop-Down Control -->
				<tr>
					<th scope="row">Color Scheme</th>
					<td>
						<select name='fblsogm_options[drp_select_box2]'>
							<option value='light' <?php selected('light', $options['drp_select_box2']); ?>>Light</option>
							<option value='dark' <?php selected('dark', $options['drp_select_box2']); ?>>Dark</option>
						</select>
						<span style="color:#666666;margin-left:2px;">The color scheme of our plugin</span>
					</td>
				</tr>
				
				<!-- Select Drop-Down Control -->
				<tr>
					<th scope="row">Verb to display</th>
					<td>
						<select name='fblsogm_options[drp_select_box3]'>
							<option value='like' <?php selected('like', $options['drp_select_box3']); ?>>Like</option>
							<option value='recommend' <?php selected('recommend', $options['drp_select_box3']); ?>>Recommend</option>
						</select>
						<span style="color:#666666;margin-left:2px;">Like or Recommend?</span>
					</td>
				</tr>				
				
				<!-- Textbox Control -->
				<tr>
					<th scope="row">Default Image URL</th>
					<td>
						<input type="text" size="57" name="fblsogm_options[txt_one]" value="<?php echo $options['txt_one']; ?>" /><span style="color:#666666;margin-left:2px;"><br />Enter full URL including http:// in this box to use if there is no featured image or any image in the posts/pages or in the content. The recommended image referenced by og:image must be at least 200px in both dimensions. You can use the WordPress <a href="media-new.php">media uploader</a> if you wish, just copy the location of the image and put it here.</span>
					</td>
				</tr>				
				
				<tr><td colspan="2"><div style="margin-top:10px;"></div></td></tr>
				<tr valign="top" style="border-top:#dddddd 1px solid;">
					<th scope="row">Database Options</th>
					<td>
						<label><input name="fblsogm_options[chk_default_options_db]" type="checkbox" value="1" <?php if (isset($options['chk_default_options_db'])) { checked('1', $options['chk_default_options_db']); } ?> /> Restore defaults upon plugin deactivation/reactivation</label>
						<br /><span style="color:#666666;margin-left:2px;">Only check this if you want to reset plugin settings upon Plugin reactivation</span>
					</td>
				</tr>
			</table>
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />

		</form>

			<br class="clear" />
						</div>
					</div>
				</div>
			</div>
		</div>
	
			<div id="side-info-column" class="inner-sidebar">
			<div class="meta-box-sortables">
				<div id="about" class="postbox">
					<h3 class="hndle" id="about-sidebar">About the Plugin:</h3>
					<div class="inside">
						<p>You are using <a href="http://tutorials.triptripper.com/facebook-like-send-opengraph-wp-plugin/" target="_blank" style="color:#72a1c6;"><strong>WP Facebook Like Send & Open Graph Meta</strong></a> Plugin v<?php echo FBLSOGM_VERSION; ?></p>
					</div>
				</div>
			</div>	
			
				<div id="about" class="postbox">
					<h3 class="hndle" id="about-sidebar">Enjoy the plugin?</h3>
					<div class="inside">		
						Why not consider <a href="http://wordpress.org/extend/plugins/wp-facebook-like-send-open-graph-meta/" target="_blank">giving it a good rating on WordPress.org</a> or <a href="http://twitter.com/?status=Facebook Like and Send Buttons Plugin for WordPress with Open Graph Meta - check it out! http://tutorials.triptripper.com/?p=144" target="_blank">Tweet about it</a>. Thanks.</p>
									<span><a href="http://www.facebook.com/pages/How-To-Tutorials-Triptrip-Tips/233542810083158" title="Our Facebook page" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/wp-facebook-like-send-open-graph-meta/images/facebook-icon.png" /></a></span>
									&nbsp;&nbsp;<span><a href="http://twitter.com/Triptrippertips" title="Follow on Twitter" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/wp-facebook-like-send-open-graph-meta/images/twitter-icon.png" /></a></span>
									&nbsp;&nbsp;<span><a href="http://tutorials.triptripper.com/" title="Tutorials.Triptripper.com" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/wp-facebook-like-send-open-graph-meta/images/pc-icon.png" /></a></span>
					</div>
				</div>

			<div id="about" class="postbox">
				<h3 class="hndle" id="about-sidebar">Donate:</h3>
				<div class="inside">
					<p>If you have found this plugin at all useful, please consider buying me a cup of coffee. Thank you!<br />
					<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
					<input type="hidden" name="cmd" value="_s-xclick">
					<input type="hidden" name="hosted_button_id" value="XPHXDYW2PDE38">
					<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
					<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
					</form></p>
				</div>
			</div>
			
			</div>	
		
		</div>			
	</div>
	<?php	
}

// Sanitize and validate input
function fblsogm_validate_options($input) {
	 // strip html from textboxes
	$input['txt_one'] =  wp_filter_nohtml_kses($input['txt_one']); // Sanitize textbox input (strip html tags, and escape characters)
	return $input;
}

// Display a Settings link on the main Plugins page
function fblsogm_plugin_action_links( $links, $file ) {

	if ( $file == plugin_basename( __FILE__ ) ) {
		$fblsogm_links = '<a href="'.get_admin_url().'options-general.php?page=fblsogm">'.__('Settings').'</a>';
		// make the 'Settings' link appear first
		array_unshift( $links, $fblsogm_links );
	}

	return $links;
}

// ------------------------------------------------------------------------------
// OUR PLUGIN FUNCTIONS:
// ------------------------------------------------------------------------------

function fblsogm_like_send_wp($content){
	$options = get_option('fblsogm_options');

	$layout = $options['drp_select_layout'];
	if($layout == '') { $layout = 'standard'; }
	
	$show_faces = $options['drp_select_box'];
	if($show_faces == '') { $show_faces = 'true'; }
	
	$colorscheme = $options['drp_select_box2'];
	if($colorscheme == '') { $colorscheme = 'light'; }
	
	$action = $options['drp_select_box3'];
	if($action == '') { $action = 'like'; }
	
	$font = $options['drp_select_font'];
	if($font == '') { $font = 'arial'; }
	
	$fb = '<div id="fb-root"></div><script src="http://connect.facebook.net/en_US/all.js#xfbml=1"></script><fb:like href="'.get_permalink($post->id).'" send="true" layout="'.$layout.'" width="400" show_faces="'.$show_faces.'" font="'.$font.'" action="'.$action.'" colorscheme="'.$colorscheme.'"></fb:like>';

if(!is_feed() && !is_home()) {
	$content .= $fb;
		} else if ( isset($options['chk_button1']) && ($options['chk_button1']!="") ) { 
	$content .= $fb;
	}
return $content;
}

add_action('the_content', 'fblsogm_like_send_wp');



//Adding the Open Graph in the Language Attributes
function fblsogm_add_og_doctype_wp( $output ) {
		return $output . ' xmlns:og="http://opengraphprotocol.org/schema/" xmlns:fb="http://www.facebook.com/2008/fbml"';
	}
add_filter('language_attributes', 'fblsogm_add_og_doctype_wp');

add_action('wp_head', 'fblsogm_add_facebook_og_wp');

function fblsogm_add_facebook_og_wp() {
	global $post,$posts;
	
		// get image
		if(function_exists('get_post_thumbnail_id')){
			$catch_thumbs = wp_get_attachment_image_src(get_post_thumbnail_id($post->id), 'large');
			$catch_thumb = $catch_thumbs[0];
		}

		// If there is no featured image or any image, search post for images and display first one. If none exists, then show the default url.
		if($catch_thumb[0] == ''){
				$out = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $match);
				if ( $out > 0 ){
					$catch_thumb = $match[1][0];					
				} else {
			$options = get_option('fblsogm_options');
			$catch_thumb = $options['txt_one'];
			}
		}
		
		$excerpt = ""; 
		if (has_excerpt($post->ID)) {
			$excerpt = esc_attr(strip_tags(get_the_excerpt($post->ID)));
		}else{
			$excerpt = esc_attr(str_replace("\r\n",' ',substr(strip_tags(strip_shortcodes($post->post_content)), 0, 160)));
		}
		
		$site_description = get_bloginfo( 'description', 'display' );

?>

<!-- Facebook Open Graph Tags added by WP Facebook Like Send & Open Graph Meta v<?php echo FBLSOGM_VERSION; ?>: http://tutorials.triptripper.com/facebook-like-send-opengraph-wp-plugin/ -->
<meta property="og:title" content="<?php global $page, $paged; if (is_single() || is_page() ) { echo wp_title('', false, 'right');} else { echo wp_title( '|', false, 'right' ); bloginfo( 'name' );  if ( $site_description && ( is_home() || is_front_page() ) ) echo " | $site_description"; if ( $paged >= 2 || $page >= 2 ) echo ' | ' . sprintf( 'Page %s', max( $paged, $page ) );} ?>" />
<meta property="og:type" content="<?php if (is_single() || is_page()) { echo "article"; } else { echo "website";} ?>" />
<meta property="og:image" content="<?php echo $catch_thumb; ?>" />
<meta property="og:site_name" content="<?php bloginfo('name'); ?>" />
<meta property="og:description" content="<?php if (is_singular()) { echo $excerpt;} else {echo $site_description;} ?>" />
<?php echo '<meta property="og:url" content="http://'.$_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'].'" />'; ?>

<!-- Facebook Open Graph Tags end -->

<?php

	}
?>